IssueNumber Title
#################

Update the title above with your issue number and a 1-2 word title.
Your filename should be issuenumber-title.rst, substituting appropriately.

Make sure to fill out any section that represents changes you have made,
or replace the default bullet point with N/A.

API Breaks
----------
- List backwards-incompatible changes here.
  Changes to PVs don't count as API changes for this library,
  but changing method and component names or changing default behavior does.

Features
--------
- List new updates that add utility to many classes,
  provide a new base classes, add options to helper methods, etc.

Bugfixes
--------
- List bug fixes that are not covered in the above sections.

Maintenance
-----------
- List anything else. The intent is to accumulate changes
  that the average user does not need to worry about.

Contributors
------------
- List your github username and anyone else who made significant
  code or conceptual contributions to the PR. You don't need to
  add reviewers unless their suggestions lead to large rewrites.
  These will be used in the release notes to give credit and to
  notify you when your code is being tagged.
